Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
tests / unit / no_torch / test_bool_array.py |  | 31 | 0 | 0 |  | 100%
tests / unit / no_torch / test_dataframe_serialization.py |  | 66 | 0 | 0 |  | 100%
tests / unit / no_torch / test_isolate_zanj_handler_store.py |  | 47 | 1 | 0 |  | 98%
tests / unit / no_torch / test_load_item_recursive.py |  | 86 | 1 | 0 |  | 99%
tests / unit / no_torch / test_loading_edge_cases.py |  | 105 | 8 | 0 |  | 92%
tests / unit / no_torch / test_serializing_edge_cases.py |  | 60 | 0 | 0 |  | 100%
tests / unit / no_torch / test_shared_prefix_keys.py |  | 22 | 0 | 0 |  | 100%
tests / unit / no_torch / test_zanj_basic.py |  | 73 | 0 | 0 |  | 100%
tests / unit / no_torch / test_zanj_edge_cases.py |  | 147 | 2 | 0 |  | 99%
tests / unit / no_torch / test_zanj_populate_nested.py |  | 24 | 0 | 0 |  | 100%
tests / unit / no_torch / test_zanj_serializable_dataclass.py |  | 91 | 0 | 0 |  | 100%
tests / unit / with_torch / test_bool_array_torch.py |  | 19 | 0 | 0 |  | 100%
tests / unit / with_torch / test_get_module_device.py |  | 33 | 1 | 0 |  | 97%
tests / unit / with_torch / test_sdc_torch.py |  | 59 | 1 | 0 |  | 98%
tests / unit / with_torch / test_torch_edge_cases.py |  | 108 | 5 | 0 |  | 95%
tests / unit / with_torch / test_torchutil_edge_cases.py |  | 115 | 4 | 0 |  | 97%
tests / unit / with_torch / test_zanj_sdc_modelcfg.py |  | 90 | 0 | 0 |  | 100%
tests / unit / with_torch / test_zanj_torch.py |  | 88 | 4 | 0 |  | 95%
tests / unit / with_torch / test_zanj_torch_cfgmismatch.py |  | 59 | 3 | 0 |  | 95%
zanj / __init__.py |  | 4 | 0 | 0 |  | 100%
zanj / consts.py |  | 7 | 2 | 0 |  | 71%
zanj / externals.py |  | 21 | 1 | 0 |  | 95%
zanj / loading.py |  | 139 | 13 | 0 |  | 91%
zanj / serializing.py |  | 74 | 0 | 0 |  | 100%
zanj / torchutil.py |  | 116 | 3 | 0 |  | 97%
zanj / zanj.py |  | 83 | 1 | 0 |  | 99%
Total |  | 1767 | 50 | 0 |  | 97%

No items found using the specified filter.